@@ -159,8 +159,12 @@ class GithubHandler(urllib2.BaseHandler):
                 new_url = urlparse.urlunparse((scheme, netloc, path, params,
                                                query, fragment))
                 timeout = getattr(req, 'timeout', 60)
+                old_req = req
                 req = urllib2.Request(new_url)
                 req.timeout = timeout
+                # Re-add user-agent, as the GitHub API requires this for auth
+                req.add_header('user-agent', old_req.get_header('user-agent',
+                                                            'Python-urllib2'))
             else:
                 log.debug("Github url %r blocked by buildout.github-repos" %
                           (url,))
@@ -254,11 +258,15 @@ def install(buildout=None, pwd_path=None):
             new_handlers.append(GithubHandler(github_creds, github_repos))
         if pwdsf:
             for l, row in enumerate(csv.reader(pwdsf)):
-                if len(row) != 4:
+                if len(row) == 3:
+                    realm, uris, user = (el.strip() for el in row)
+                    password = prompt_passwd(realm, user)
+                elif len(row) == 4:
+                    realm, uris, user, password = (el.strip() for el in row)
+                else:
                     raise RuntimeError(
                         "Authentication file cannot be parsed %s:%s" % (
                             pwd_path, l + 1))
-                realm, uris, user, password = (el.strip() for el in row)
                 creds.append((realm, uris, user, password))
                 log.debug('Added credentials %r, %r' % (realm, uris))
                 auth_handler.add_password(realm, uris, user, password)
@@ -279,6 +287,12 @@ def install(buildout=None, pwd_path=None):
             pwdsf.close()
 
 
+def prompt_passwd(realm, user):
+    from getpass import getpass
+    password = getpass('>>> Password for {} - {}: '.format(realm, user))
+    return password
+
+
 class URLOpener(download.URLOpener):
 
     def __init__(self, creds, github_creds, github_repos):
